@@ -37,6 +37,8 @@ from .m032_cleanup_orphaned_branch_relationships import Migration032
 from .m033_deduplicate_relationship_vertices import Migration033
 from .m034_find_orphaned_schema_fields import Migration034
 from .m035_orphan_relationships import Migration035
+from .m036_drop_attr_value_index import Migration036
+from .m037_index_attr_vals import Migration037
 
 if TYPE_CHECKING:
     from infrahub.core.root import Root
@@ -79,6 +81,8 @@ MIGRATIONS: list[type[GraphMigration | InternalSchemaMigration | ArbitraryMigrat
     Migration033,
     Migration034,
     Migration035,
+    Migration036,
+    Migration037,
 ]
 
 
