@@ -13,19 +13,18 @@ from infrahub.core.schema import GenericSchema, NodeSchema
 from infrahub.core.validators.aggregated_checker import AggregatedConstraintChecker
 from infrahub.core.validators.model import SchemaConstraintValidatorRequest, SchemaViolation
 from infrahub.dependencies.registry import get_component_registry
-from infrahub.services import InfrahubServices  # noqa: TC001  needed for prefect flow
+from infrahub.workers.dependencies import get_database
 from infrahub.workflows.utils import add_tags
 
 from .models.validate_migration import SchemaValidateMigrationData, SchemaValidatorPathResponseData
 
 if TYPE_CHECKING:
     from infrahub.core.schema.schema_branch import SchemaBranch
+    from infrahub.database import InfrahubDatabase
 
 
 @flow(name="schema_validate_migrations", flow_run_name="Validate schema migrations", persist_result=True)
-async def schema_validate_migrations(
-    message: SchemaValidateMigrationData, service: InfrahubServices
-) -> list[SchemaValidatorPathResponseData]:
+async def schema_validate_migrations(message: SchemaValidateMigrationData) -> list[SchemaValidatorPathResponseData]:
     batch = InfrahubBatch(return_exceptions=True)
     log = get_run_logger()
     await add_tags(branches=[message.branch.name])
@@ -47,7 +46,7 @@ async def schema_validate_migrations(
             node_schema=schema,
             schema_path=constraint.path,
             schema_branch=message.schema_branch,
-            service=service,
+            database=await get_database(),
         )
 
     results = [result async for _, result in batch.execute()]
@@ -67,9 +66,9 @@ async def schema_path_validate(
     node_schema: NodeSchema | GenericSchema,
     schema_path: SchemaPath,
     schema_branch: SchemaBranch,
-    service: InfrahubServices,
+    database: InfrahubDatabase,
 ) -> SchemaValidatorPathResponseData:
-    async with service.database.start_session(read_only=True) as db:
+    async with database.start_session(read_only=True) as db:
         constraint_request = SchemaConstraintValidatorRequest(
             branch=branch,
             constraint_name=constraint_name,
