@@ -76,6 +76,32 @@ class RepositoryError(Error):
         super().__init__(self.message)
 
 
+class RepositoryConnectionError(RepositoryError):
+    def __init__(self, identifier: str, message: str | None = None) -> None:
+        super().__init__(
+            identifier=identifier,
+            message=message
+            or f"Unable to clone the repository {identifier}, please check the address and the credential",
+        )
+
+
+class RepositoryCredentialsError(RepositoryError):
+    def __init__(self, identifier: str, message: str | None = None) -> None:
+        super().__init__(
+            identifier=identifier,
+            message=message or f"Authentication failed for {identifier}, please validate the credentials.",
+        )
+
+
+class RepositoryInvalidBranchError(RepositoryError):
+    def __init__(self, identifier: str, branch_name: str, location: str, message: str | None = None) -> None:
+        super().__init__(
+            identifier=identifier,
+            message=message
+            or f"The branch {branch_name} isn't a valid branch for the repository {identifier} at {location}.",
+        )
+
+
 class RepositoryInvalidFileSystemError(RepositoryError):
     def __init__(
         self,
@@ -83,9 +109,11 @@ class RepositoryInvalidFileSystemError(RepositoryError):
         directory: Path,
         message: str | None = None,
     ) -> None:
-        super().__init__(identifier=identifier)
+        super().__init__(
+            identifier=identifier,
+            message=message or f"Invalid file system for {identifier}, Local directory {directory} missing.",
+        )
         self.directory = directory
-        self.message = message or f"Invalid file system for {identifier}, Local directory {directory} missing."
 
 
 class CommitNotFoundError(Error):
@@ -293,34 +321,25 @@ class ValidationError(Error):
 
     def __init__(self, input_value: str | dict | list) -> None:
         self.message = ""
-        self.location = None
-        self.messages = {}
 
         if isinstance(input_value, str):
             self.message = input_value
-        elif isinstance(input_value, dict) and len(input_value) == 1:
-            self.message = list(input_value.values())[0]
-            self.location = list(input_value.keys())[0]
-        elif isinstance(input_value, dict) and len(input_value) > 1:
-            for key, value in input_value.items():
-                self.messages[key] = value
-
+        elif isinstance(input_value, dict):
+            self.message = ", ".join([f"{message} at {location}" for location, message in input_value.items()])
         elif isinstance(input_value, list):
-            for item in input_value:
-                if isinstance(item, self.__class__):
-                    self.messages[item.location] = item.message
-                elif isinstance(item, dict):
-                    for key, value in item.items():
-                        self.messages[key] = value
+            if all(isinstance(item, ValidationError) for item in input_value):
+                self.message = ", ".join([validation_error.message for validation_error in input_value])
+            if all(isinstance(item, dict) for item in input_value):
+                messages = []
+                for item in input_value:
+                    messages.append(", ".join([f"{message} at {location}" for location, message in item.items()]))
+                self.message = ", ".join(messages)
+
+        if not self.message:
+            raise ValueError("Could not build validation error message")
 
         super().__init__(self.message)
 
-    def __str__(self) -> str:
-        if self.messages:
-            return ", ".join([f"{message} at {location}" for location, message in self.messages.items()])
-
-        return f"{self.message} at {self.location or '<Undefined>'}"
-
 
 class DiffError(Error):
     HTTP_CODE = 400
@@ -329,6 +348,14 @@ class DiffError(Error):
         self.message = message
 
 
+class HFIDViolatedError(ValidationError):
+    matching_nodes_ids: set[str]
+
+    def __init__(self, input_value: str | dict | list, matching_nodes_ids: set[str]) -> None:
+        self.matching_nodes_ids = matching_nodes_ids
+        super().__init__(input_value)
+
+
 class DiffRangeValidationError(DiffError): ...
 
 
