@@ -54,10 +54,11 @@ class InfrahubCoreMenuMutation(InfrahubMutationMixin, Mutation):
         data: InputObjectType,
         branch: Branch,
         database: InfrahubDatabase | None = None,  # noqa: ARG003
+        override_data: dict[str, Any] | None = None,
     ) -> tuple[Node, Self]:
         validate_namespace(data=data)
 
-        obj, result = await super().mutate_create(info=info, data=data, branch=branch)
+        obj, result = await super().mutate_create(info=info, data=data, branch=branch, override_data=override_data)
 
         return obj, result
 
