@@ -1,13 +1,11 @@
-from typing import Optional
-
 from pydantic import BaseModel
 
 
 class BranchCreateModel(BaseModel):
     name: str
-    id: Optional[str] = None
+    id: str | None = None
     description: str = ""
     origin_branch: str = "main"
-    branched_from: Optional[str] = None
+    branched_from: str | None = None
     sync_with_git: bool = True
     is_isolated: bool = True
