@@ -1,14 +1,11 @@
 import ujson
 from prefect import Flow
 
+from infrahub.log import get_logger
 from infrahub.message_bus import RPCErrorResponse, messages
-from infrahub.message_bus.operations import (
-    git,
-    refresh,
-    send,
-)
+from infrahub.message_bus.operations import git, refresh, send
 from infrahub.message_bus.types import MessageTTL
-from infrahub.services import InfrahubServices
+from infrahub.services.adapters.message_bus import InfrahubMessageBus
 from infrahub.tasks.check import set_check_status
 
 COMMAND_MAP = {
@@ -22,7 +19,7 @@ COMMAND_MAP = {
 
 
 async def execute_message(
-    routing_key: str, message_body: bytes, service: InfrahubServices, skip_flow: bool = False
+    routing_key: str, message_body: bytes, message_bus: InfrahubMessageBus, skip_flow: bool = False
 ) -> MessageTTL | None:
     message_data = ujson.loads(message_body)
     message = messages.MESSAGE_MAP[routing_key](**message_data)
@@ -31,16 +28,16 @@ async def execute_message(
         func = COMMAND_MAP[routing_key]
         if skip_flow and isinstance(func, Flow):
             func = func.fn
-        await func(message=message, service=service)
+        await func(message=message)
     except Exception as exc:
         if message.reply_requested:
             response = RPCErrorResponse(errors=[str(exc)], initial_message=message.model_dump())
-            await service.message_bus.reply_if_initiator_meta(message=response, initiator=message)
+            await message_bus.reply_if_initiator_meta(message=response, initiator=message)
             return None
         if message.reached_max_retries:
-            service.log.exception("Message failed after maximum number of retries", error=exc)
-            await set_check_status(message, conclusion="failure", service=service)
+            get_logger().exception("Message failed after maximum number of retries", error=exc)
+            await set_check_status(message, conclusion="failure")
             return None
         message.increase_retry_count()
-        await service.message_bus.send(message, delay=MessageTTL.FIVE, is_retry=True)
+        await message_bus.send(message, delay=MessageTTL.FIVE, is_retry=True)
         return MessageTTL.FIVE
