@@ -9,7 +9,9 @@ if TYPE_CHECKING:
     from infrahub.core.ipam.constants import IPNetworkType
 
 
-def get_next_available_prefix(pool: IPSet, prefix_length: int, prefix_ver: Literal[4, 6] = 4) -> IPNetworkType:
+def get_next_available_prefix(
+    pool: IPSet, prefix_length: int | None = None, prefix_ver: Literal[4, 6] = 4
+) -> IPNetworkType:
     """Get the next available prefix of a given prefix length from an IPSet.
 
     Args:
@@ -20,10 +22,7 @@ def get_next_available_prefix(pool: IPSet, prefix_length: int, prefix_ver: Liter
     Raises:
         ValueError: If there are no available subnets in the pool
     """
-    prefix_ver_map = {
-        4: ipaddress.IPv4Network,
-        6: ipaddress.IPv6Network,
-    }
+    prefix_ver_map = {4: ipaddress.IPv4Network, 6: ipaddress.IPv6Network}
 
     filtered_pool = IPSet([])
     for subnet in pool.iter_cidrs():
@@ -31,6 +30,9 @@ def get_next_available_prefix(pool: IPSet, prefix_length: int, prefix_ver: Liter
             filtered_pool.add(subnet)
 
     for cidr in filtered_pool.iter_cidrs():
+        if prefix_length is None:
+            return cidr
+
         if cidr.prefixlen <= prefix_length:
             next_available = ipaddress.ip_network(f"{cidr.network}/{prefix_length}")
             return next_available
