@@ -5,13 +5,8 @@ from typing import TYPE_CHECKING, Any
 if TYPE_CHECKING:
     import httpx
 
-    from infrahub.services import InfrahubServices
-
 
 class InfrahubHTTP:
-    async def initialize(self, service: InfrahubServices) -> None:
-        """Initialize the HTTP adapter"""
-
     async def get(
         self,
         url: str,
