@@ -59,6 +59,8 @@ PROJECT_ENV_VARIABLES: dict[str, str] = {
     "INFRAHUB_TESTING_PREFECT_UI_ENABLED": "true",
     "INFRAHUB_TESTING_DOCKER_PULL": "true",
     "INFRAHUB_TESTING_SCHEMA_STRICT_MODE": "true",
+    "INFRAHUB_TESTING_TASKMGR_API_WORKERS": "1",
+    "INFRAHUB_TESTING_TASKMGR_BACKGROUND_SVC_REPLICAS": "0",
 }
 
 
@@ -144,6 +146,21 @@ class InfrahubDockerCompose(DockerCompose):
                     "NEO4J_DOCKER_IMAGE": "neo4j:2025.03.0-enterprise",
                 }
             )
+        if os.environ.get("INFRAHUB_TESTING_TASKMGR_SCALEOUT"):
+            PROJECT_ENV_VARIABLES.update(
+                {
+                    "INFRAHUB_TESTING_TASKMGR_BACKGROUND_SVC_REPLICAS": "1",
+                    "PREFECT_MESSAGING_BROKER": "prefect_redis.messaging",
+                    "PREFECT_MESSAGING_CACHE": "prefect_redis.messaging",
+                    "PREFECT__SERVER_WEBSERVER_ONLY": "true",
+                    "PREFECT_API_DATABASE_MIGRATE_ON_START": "false",
+                    "PREFECT_API_BLOCKS_REGISTER_ON_START": "false",
+                    "PREFECT_SERVER_SERVICES_EVENT_LOGGER_ENABLED": "false",
+                    "PREFECT_SERVER_SERVICES_EVENT_PERSISTER_ENABLED": "false",
+                    "PREFECT_SERVER_SERVICES_TRIGGERS_ENABLED": "false",
+                    "PREFECT_SERVER_SERVICES_TASK_RUN_RECORDER_ENABLED": "false",
+                }
+            )
 
         with env_file.open(mode="w", encoding="utf-8") as file:
             for key, value in PROJECT_ENV_VARIABLES.items():
